.. image:: https://travis-ci.org/jbn/bandits.svg?branch=master
    :target: https://travis-ci.org/jbn/bandits
.. image:: https://ci.appveyor.com/api/projects/status/69kj3prrrieyp8q2/branch/master?svg=true
    :target: https://ci.appveyor.com/project/jbn/bandits/branch/master 
.. image:: https://img.shields.io/pypi/dm/bandits.svg
    :target: https://pypi.python.org/pypi/bandits
.. image:: https://coveralls.io/repos/github/jbn/bandits/badge.svg?branch=master
    :target: https://coveralls.io/github/jbn/bandits?branch=master 
.. image:: https://img.shields.io/pypi/v/bandits.svg
    :target: https://pypi.python.org/pypi/bandits
.. image:: https://img.shields.io/pypi/pyversions/bandits.svg
    :target: https://pypi.python.org/pypi/bandits


=======
bandits
=======

Multi-armed bandits in Python
